==> hermit-0.34.0.tar.gz: hermit-0.34.0/README.md <==
<a href="https://www.vecteezy.com/vector-art/292320-hermit-crab-on-white-background" title="Hermit Crab by Vecteezy">
<img align="right" width="100" height="100" src="./docs/static/images/logo.svg" alt="Hermit">
</a>

# Hermit - uniform tooling for Linux and Mac
[![CI](https://github.com/cashapp/hermit/actions/workflows/ci.yml/badge.svg)](https://github.com/cashapp/hermit/actions/workflows/ci.yml) [![Slack chat](https://img.shields.io/badge/slack-gophers-795679?logo=slack)](https://gophers.slack.com/messages/cashapp) [![Go Report Card](https://goreportcard.com/badge/github.com/cashapp/hermit)](https://goreportcard.com/report/github.com/cashapp/hermit)

Hermit installs tools for software projects in self-contained, isolated sets, so your team, your contributors, and your CI have the same consistent tooling.

See https://cashapp.github.io/hermit for full documentation.

![hermit intro screen cast](docs/static/screencasts/using.svg)

---

Copyright 2021 Square, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

==> hermit-0.38.1.tar.gz: hermit-0.38.1/README.md <==
<a href="https://www.vecteezy.com/vector-art/292320-hermit-crab-on-white-background" title="Hermit Crab by Vecteezy">
<img align="right" width="100" height="100" src="./docs/docs/img/logo.svg" alt="Hermit">
</a>

# Hermit - uniform tooling for Linux and Mac
[![CI](https://github.com/cashapp/hermit/actions/workflows/ci.yml/badge.svg)](https://github.com/cashapp/hermit/actions/workflows/ci.yml) [![Slack chat](https://img.shields.io/badge/slack-gophers-795679?logo=slack)](https://gophers.slack.com/messages/cashapp) [![Go Report Card](https://goreportcard.com/badge/github.com/cashapp/hermit)](https://goreportcard.com/report/github.com/cashapp/hermit)

Hermit installs tools for software projects in self-contained, isolated sets, so your team, your contributors, and your CI have the same consistent tooling.

See https://cashapp.github.io/hermit for full documentation.

![hermit intro screen cast](docs/docs/static/screencasts/using.svg)

---

Copyright 2021 Square, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
